@@ -1,10 +1,11 @@
 package Wubot::Reactor::WebFetch;
 use Moose;
 
-our $VERSION = '0.1_10'; # VERSION
+our $VERSION = '0.2_001'; # VERSION
 
 use Wubot::Util::WebFetcher;
 
+use Log::Log4perl;
 use YAML;
 
 has 'fetcher' => ( is  => 'ro',
@@ -15,6 +16,15 @@ has 'fetcher' => ( is  => 'ro',
                    },
                );
 
+has 'logger'  => ( is => 'ro',
+                   isa => 'Log::Log4perl::Logger',
+                   lazy => 1,
+                   default => sub {
+                       return Log::Log4perl::get_logger( __PACKAGE__ );
+                   },
+               );
+
+
 sub react {
     my ( $self, $message, $config ) = @_;
 
@@ -36,6 +46,8 @@ sub react {
         return $message;
     }
 
+    $self->logger->debug( "Fetching content from $url" );
+
     my $content;
     eval {                          # try
         $content = $self->fetcher->fetch( $url, $config );
@@ -71,7 +83,7 @@ Wubot::Reactor::WebFetch - fetch data from a URL
 
 =head1 VERSION
 
-version 0.1_10
+version 0.2_001
 
 =head1 SYNOPSIS
 
